@@ -569,14 +569,9 @@ def resolve_viewspec(viewspec, stack_depth):
         raise ValueError("Expected string like 'package.module:view_func';"\
                          " got %r'" % viewspec)
 
-    stack = inspect.stack()
-    try:
-        frame = stack[stack_depth][0]
-        ob = __import__(module_spec, frame.f_globals, frame.f_locals)
-        for mod in module_spec.split('.')[1:]:
-            ob = getattr(ob, mod)
-    finally:
-        del stack
+    ob = __import__(module_spec)
+    for mod in module_spec.split('.')[1:]:
+        ob = getattr(ob, mod)
 
     for attr in attr_spec.split('.'):
         ob = getattr(ob, attr)
